#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-lua
version:              0.2.3.2
visibility:           public
id:                   tasty-lua-0.2.3.2-3Kfx74XQv3326NhbjKFzAz
key:                  tasty-lua-0.2.3.2-3Kfx74XQv3326NhbjKFzAz
license:              MIT
copyright:            © 2019–2020 Albert Krewinkel <albert+hslua@zeitkraut.de>
maintainer:           albert+hslua@zeitkraut.de
author:               Albert Krewinkel
homepage:             https://github.com/hslua/tasty-lua
synopsis:             Write tests in Lua, integrate into tasty.
description:          Allow users to define tasty tests from Lua.
category:             Foreign
abi:                  342e4168c3aa70cd8c2ba9cfe4e77eac
exposed:              True
exposed-modules:
    Test.Tasty.Lua Test.Tasty.Lua.Core Test.Tasty.Lua.Module
    Test.Tasty.Lua.Translate

import-dirs:          /usr/lib/ghc-8.10.5/site-local/tasty-lua-0.2.3.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/tasty-lua-0.2.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/tasty-lua-0.2.3.2
hs-libraries:         HStasty-lua-0.2.3.2-3Kfx74XQv3326NhbjKFzAz
depends:
    base-4.14.2.0 bytestring-0.10.12.0
    file-embed-0.0.14.0-GfeXRY82mmWF3g3U2v7jH5
    hslua-1.3.0.1-KD3ebwQ5HMbCfq1Rgfo8gC
    tasty-1.4.1-DoD4Mv0vTnM7HUpIQvrq31 text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-tasty-lua/html/tasty-lua.haddock
haddock-html:         /usr/share/doc/haskell-tasty-lua/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

